<?php

define('PHPWG_ROOT_PATH','../../');
include_once( PHPWG_ROOT_PATH.'include/common.inc.php' );

if (!defined('RVAC_ID')) {
  set_status_header(501);
  exit;
}

include_once( 'functions.inc.php' );

$page['root_path'] = get_absolute_root_url(false);

$context = @$_REQUEST['context'];

if (empty($context) || strncmp($context, '$t/',3))
	bad_request("context");

$tag_ids = array();
$tag_url_names = array();
foreach( explode('/', $context) as $tag_token)
{
	if ( $conf['tag_url_style'] != 'tag' and preg_match('/^(\d+)(?:-(.*)|)$/', $tag_token, $matches) )
	{
		$tag_ids[] = $matches[1];
	}
	else
	{
		$tag_url_names[] =  $tag_token;
	}
}

$context_tags = find_tags($tag_ids, $tag_url_names);
if ( empty($context_tags) )
{
	bad_request('no context content');
}

$context_tag_ids = array_map( function($tag) { return $tag['id']; }, $context_tags);
$context_image_ids = get_image_ids_for_tags($context_tag_ids);

$tags = get_common_tags($context_image_ids, -1, $context_tag_ids);
usort($tags, function($a,$b) {
	$d = -$a['counter'] + $b['counter'];
	if (!$d) $d = tag_alpha_compare($a,$b);
	return $d;
});

// remove non filtering tags
$max = intval(0.9*count($context_image_ids));
while( count($tags) && $tags[0]['counter'] >= $max)
	array_shift($tags);
$tags = trigger_event('rvac_filter_context_tags', $tags);

$suggestions = array();
foreach($tags as $tag)
{
	$label = $tag['name'];

	$url = $context.'/';
	switch ( $conf['tag_url_style'] )
	{
		case 'id':
			$url.= $tag['id'];
			break;
		case 'tag':
			if (!is_numeric($tag['url_name']) )
			{
				$url.= $tag['url_name'];
				break;
			}
		default:
			$url.= $tag['id'].'-'.$tag['url_name'];
	}

	$suggestion = array(
    'label' => $label,
    'value' => $url,
		'w' => intval($tag['counter'])
	);
	
	$q = rvac_normalize($label);
  if ($q != strtolower($label))
    $suggestion['q'] = $q;

	$suggestions[] = $suggestion;
}



$ds = str_replace(
  array('\\/', '"q":', '"label":', '"value":', '"w":'),
  array('/', 'q:', 'label:', 'value:', 'w:'),
  json_encode($suggestions));

$js = 'RVAC.mergeData({dataSource:'.$ds.',
ctxq:'.json_encode((string)@$_REQUEST['ctxq']).',
ctxl:'.json_encode((string)@$_REQUEST['ctxl']).',
ctxw:'.count($context_image_ids).'
})';

header("Content-Type: application/javascript; charset=".get_pwg_charset());
$expires = time() + 300;
header("Pragma:");
header("Cache-control: private, max-age=300");
header('Expires: '.gmdate('D, d M Y H:i:s', $expires).' GMT');

echo $js;

?>